@@ -93,8 +93,8 @@ KviMdiManager::KviMdiManager(TQWidget * parent,KviFrame * pFrm,const char * name
 	resizeContents(width(),height());
 
 #ifdef COMPILE_USE_QT4
-	setFocusPolicy(TTQ_NoFocus);
-	viewport()->setFocusPolicy(TTQ_NoFocus);
+	setFocusPolicy(TQ_NoFocus);
+	viewport()->setFocusPolicy(TQ_NoFocus);
 #else
 	setFocusPolicy(TQ_NoFocus);
 	viewport()->setFocusPolicy(TQ_NoFocus);
