@@ -257,7 +257,7 @@ static int mod_cod[] =	{
 		!fn: <integer> $lineOfChar(<paragraph:integer>,<index:integer>)
 		Returns the line number of the line in paragraph par in which the character at position index appears.[br]
 		If there is no such paragraph or no such character at the index position  -1 is returned.
-		!fn: <integer> $paragraphLenght(<paragraph:integer>)
+		!fn: <integer> $paragraphLength(<paragraph:integer>)
 		Returns the length of the paragraph par, or -1 if there is no paragraph with index par.
 
 */
